@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Text, Any
+from typing import Any, Text
 
 
 class ScreenOrientation(Enum):
@@ -70,6 +70,11 @@ class DeviceName(Enum):
     OnePlus_7T_Pro = "OnePlus 7T Pro"
 
 
+class IosVersion(Enum):
+    LATEST = "latest"
+    ONE_VERSION_BACK = "latest-1"
+
+
 class IosDeviceName(Enum):
     iPhone_11_Pro = "iPhone 11 Pro"
     iPhone_11_Pro_Max = "iPhone 11 Pro Max"
@@ -84,7 +89,7 @@ class IosDeviceName(Enum):
     iPad_Air_2 = "iPad Air (2nd generation)"
 
 
-class VisualGridOption:
+class VisualGridOption(object):
     def __init__(self, key, value):
         # type: (Text, Any) -> None
         self.key = key
