@@ -6,8 +6,8 @@ if TYPE_CHECKING:
     from selenium.webdriver.remote.webdriver import WebDriver
     from selenium.webdriver.remote.webelement import WebElement
 
+    from applitools.common.geometry import RectangleSize, Region
     from applitools.core.triggers import ActionTrigger
-    from applitools.common.geometry import Region, RectangleSize
     from applitools.selenium.webdriver import EyesWebDriver
     from applitools.selenium.webelement import EyesWebElement
 
